import{ac as i,V as t,Q as r,f as p}from"./outputWidgets.f0391a74.js";import{B as l,b}from"./Base.c690457d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="e178d34c-1bb5-4724-a180-e7c6b676acce",e._sentryDebugIdIdentifier="sentry-dbid-e178d34c-1bb5-4724-a180-e7c6b676acce")}catch{}})();const f=()=>t(t({},r(b(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:d}=s;const{ellipsis:n}=e;i();const c=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),d);return p(l,c,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=f();const g=o;export{g as A};
//# sourceMappingURL=Text.3e9cee86.js.map
