import{S as l}from"./Sidebar.428fba9e.js";import{_ as u}from"./Navbar.vue_vue_type_script_setup_true_lang.23562268.js";import{L as b,M as f,N as g}from"./icons.f7511453.js";import{d as _,eB as v,H as s,a as y,b as w,c as z,w as i,f as r}from"./outputWidgets.f0391a74.js";import{a as h}from"./asyncComputed.363f961e.js";import"./router.9521f915.js";import"./index.13fb7824.js";import{O as I}from"./organization.472ebbc1.js";import{B}from"./BaseLayout.d6b28c70.js";import"./index.0e674df9.js";import"./logo.084e5d7c.js";import"./Text.3e9cee86.js";import"./Base.c690457d.js";import"./Typography.2e02df67.js";import"./index.58e79df5.js";import"./ArrowRightOutlined.08fa31dd.js";import"./index.03310b61.js";import"./Form.1aee5650.js";import"./hasIn.23612021.js";import"./popupNotifcation.bb922524.js";import"./index.cf4c23b9.js";import"./record.6f7f627d.js";import"./pubsub.73224ce6.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[o]="0d75f3e0-1bc6-40ed-a8af-c5982fd8abca",a._sentryDebugIdIdentifier="sentry-dbid-0d75f3e0-1bc6-40ed-a8af-c5982fd8abca")}catch{}})();const U=_({__name:"Organization",setup(a){const n=v().params.organizationId,{result:t}=h(()=>I.get(n)),m=s(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),p=s(()=>{var e;return(e=t.value)==null?void 0:e.billingMetadata}),c=[{name:"Organization",items:[{name:"Projects",icon:b,path:"projects"},{name:"Editors",icon:f,path:"editors"},{name:"Billing",icon:g,path:"billing"}]}];return(e,M)=>{const d=y("router-view");return w(),z(B,null,{navbar:i(()=>[r(u,{breadcrumb:m.value,"billing-metadata":p.value},null,8,["breadcrumb","billing-metadata"])]),sidebar:i(()=>[r(l,{class:"sidebar",sections:c})]),content:i(()=>[r(d)]),_:1})}}});export{U as default};
//# sourceMappingURL=Organization.b4622329.js.map
