import{u as s}from"./index.4f7b2ab2.js";import{d,b as f,ev as b,f as n,u as r}from"./outputWidgets.f0391a74.js";import{g as l}from"./api.bf4cc15a.js";import{K as u,L as c}from"./repository.f857e596.js";import{_ as g}from"./Navbar.vue_vue_type_script_setup_true_lang.e41cca04.js";import{a as y}from"./asyncComputed.363f961e.js";import{P as _}from"./repository.b2311d69.js";import"./pubsub.73224ce6.js";import"./runnerData.e6656cbd.js";import"./url.3db2a8aa.js";import"./workspaces.0a261adb.js";import"./record.6f7f627d.js";import"./scripts.85b88d80.js";import"./envVars.2e25c3f4.js";import"./api.68844ee8.js";import"./index.cf4c23b9.js";import"./icons.f7511453.js";import"./contracts.generated.fbc14bdc.js";import"./index.9869cb58.js";import"./ant-design.3b7d3c1c.js";import"./index.8b4d6f50.js";import"./Modal.7a75e616.js";import"./Text.3e9cee86.js";import"./Base.c690457d.js";import"./Typography.2e02df67.js";import"./index.75333136.js";import"./Link.39e3774a.js";import"./Paragraph.4c6547df.js";import"./Title.18e0b53f.js";import"./index.0e674df9.js";import"./index.a76f65f2.js";import"./index.ef8659e9.js";import"./CollapsePanel.d211d636.js";import"./Timeline.ac53c0c9.js";import"./index.e5f19df8.js";import"./index.af266f0e.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.a25309a8.js";import"./Card.70d77b70.js";import"./TabPane.595c3088.js";import"./hasIn.23612021.js";import"./DownOutlined.8e9db136.js";import"./index.702fae36.js";import"./Form.1aee5650.js";import"./index.58e79df5.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="ddfadb41-10e1-4b1a-969f-01d7892ba34c",o._sentryDebugIdIdentifier="sentry-dbid-ddfadb41-10e1-4b1a-969f-01d7892ba34c")}catch{}})();const uo=d({__name:"Kanban",setup(o){const t=new _(s),e=new c("kanban"),{result:a}=y(l);return(k,w)=>{var i,m,p;return f(),b("div",null,[n(g,{"brand-name":((i=r(a))==null?void 0:i.brandName)||((m=r(a))==null?void 0:m.name),"logo-url":(p=r(a))==null?void 0:p.logoUrl},null,8,["brand-name","logo-url"]),n(u,{"kanban-repository":r(t),storage:r(e)},null,8,["kanban-repository","storage"])])}}});export{uo as default};
//# sourceMappingURL=Kanban.17a24e61.js.map
