import{C as n,A as o}from"./CollapsePanel.d211d636.js";import{T as t,A as d}from"./Timeline.ac53c0c9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="5e68b71d-374c-4d5c-85fc-013b486910d8",e._sentryDebugIdIdentifier="sentry-dbid-5e68b71d-374c-4d5c-85fc-013b486910d8")}catch{}})();n.Panel=o;n.install=function(e){return e.component(n.name,n),e.component(o.name,o),e};t.Item=d;t.install=function(e){return e.component(t.name,t),e.component(d.name,d),e};
//# sourceMappingURL=index.ef8659e9.js.map
