import{F as c,H as l}from"./outputWidgets.f0391a74.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="5eaeb42f-ec66-4d36-ab33-2f2bb3eb6164",r._sentryDebugIdIdentifier="sentry-dbid-5eaeb42f-ec66-4d36-ab33-2f2bb3eb6164")}catch{}})();const b=r=>{const e=c({loading:!0,result:null,error:null}),n=t=>(e.value={loading:!1,result:t,error:null},t),s=t=>{e.value={loading:!1,result:null,error:t}},o=async()=>(e.value={loading:!0,result:e.value.result,error:null},r().then(n).catch(s));o();const u=l(()=>e.value.loading),a=l(()=>e.value.result),d=l(()=>e.value.error);return{loading:u,result:a,error:d,refetch:o}};export{b as a};
//# sourceMappingURL=asyncComputed.363f961e.js.map
