import{d as c,eB as u,u as e,b as d,c as y,ev as _,f as a,w as o,bg as g,ar as l,ex as b,e as x,eD as w}from"./outputWidgets.f0391a74.js";import"./router.9521f915.js";import"./index.13fb7824.js";import{O as k}from"./organization.472ebbc1.js";import{a as A}from"./asyncComputed.363f961e.js";import{A as B}from"./Title.18e0b53f.js";import{A as h}from"./index.9869cb58.js";import{A as C}from"./index.e5f19df8.js";import{A as v}from"./Text.3e9cee86.js";import{C as D}from"./Card.70d77b70.js";import"./Form.1aee5650.js";import"./hasIn.23612021.js";import"./popupNotifcation.bb922524.js";import"./index.cf4c23b9.js";import"./record.6f7f627d.js";import"./pubsub.73224ce6.js";import"./Base.c690457d.js";import"./Typography.2e02df67.js";import"./TabPane.595c3088.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="5c68b81a-7154-45f6-ab17-45833906f2a5",t._sentryDebugIdIdentifier="sentry-dbid-5c68b81a-7154-45f6-ab17-45833906f2a5")}catch{}})();const I={key:1},N={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},Y=c({__name:"Billing",setup(t){const n=u().params.organizationId,{loading:f,result:m}=A(()=>k.get(n));return(z,T)=>e(f)?(d(),y(e(g),{key:0})):(d(),_("div",I,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(B),{level:3},{default:o(()=>[l("Current plan")]),_:1}),b("",!0)]),_:1}),a(e(C),{style:{"margin-top":"0"}}),a(e(D),{style:{width:"300px"}},{default:o(()=>{var i,s,p;return[a(e(v),{type:"secondary"},{default:o(()=>[l("Plan")]),_:1}),x("div",N,w((p=(s=(i=e(m))==null?void 0:i.billingMetadata)==null?void 0:s.plan)!=null?p:"No active plan"),1)]}),_:1})]))}});export{Y as default};
//# sourceMappingURL=Billing.07124b3f.js.map
