import"./outputWidgets.f0391a74.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="90ed5fe8-51b8-4eb9-9d4f-c972f7d5f8f6",e._sentryDebugIdIdentifier="sentry-dbid-90ed5fe8-51b8-4eb9-9d4f-c972f7d5f8f6")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}},c=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([s,f])=>{t.searchParams.delete(s),n.set(s,f)}),`${t.origin}${t.pathname}?${n.toString()}`};export{d as i,c as m};
//# sourceMappingURL=url.3db2a8aa.js.map
