import{_ as w}from"./logo.084e5d7c.js";import{v as x,b as n,ev as k,eE as B,eF as M,e as A,d as v,eA as D,a as S,u as e,c as l,bg as N,w as a,f as s,ar as i,eD as d,bG as m,cE as b,cA as E,eM as V,eJ as R,ex as y,eC as T,f5 as F,aD as P}from"./outputWidgets.f0391a74.js";import{b as h}from"./router.9521f915.js";import{a as $}from"./asyncComputed.363f961e.js";import{A as C}from"./Text.3e9cee86.js";import{A as j,B as z,a as G,c as H}from"./index.58e79df5.js";import{A as J}from"./index.03310b61.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="22767dab-97a5-4988-a6ea-81ccca158b48",o._sentryDebugIdIdentifier="sentry-dbid-22767dab-97a5-4988-a6ea-81ccca158b48")}catch{}})();const U={},I=o=>(B("data-v-439be421"),o=o(),M(),o),q={class:"logo"},K=I(()=>A("img",{class:"logo-img",src:w,alt:"Abstra cloud logo"},null,-1)),O=I(()=>A("span",null,"Abstra Cloud",-1)),Q=[K,O];function W(o,t){return n(),k("div",q,Q)}const X=x(U,[["render",W],["__scopeId","data-v-439be421"]]),Y=v({__name:"LoginBlock",setup(o){function t(f){const g=f.split("@")[0];return V.exports.kebabCase(g).toUpperCase().split("-").slice(0,2).map(p=>p[0]).join("")}const u=D(),{result:c,loading:r,refetch:_}=$(async()=>h.getAuthor());function L(){h.removeAuthor(),_(),u.push({name:"login"})}return(f,g)=>{const p=S("router-link");return e(r)?(n(),l(e(N),{key:0})):e(c)?(n(),l(e(E),{key:1,placement:"bottomRight"},{content:a(()=>[s(e(b),{direction:"vertical"},{default:a(()=>[s(e(C),null,{default:a(()=>[i(d(e(c).claims.email),1)]),_:1}),s(e(m),{onClick:L},{default:a(()=>[i("Logout")]),_:1})]),_:1})]),default:a(()=>[s(e(b),{align:"center",style:{cursor:"pointer"}},{default:a(()=>[s(e(j),null,{default:a(()=>[i(d(t(e(c).claims.email)),1)]),_:1})]),_:1})]),_:1})):(n(),l(e(m),{key:2},{default:a(()=>[s(p,{to:"/login"},{default:a(()=>[i("Login")]),_:1})]),_:1}))}}}),ne=v({__name:"Navbar",props:{breadcrumb:{},billingMetadata:{}},setup(o){return(t,u)=>(n(),l(e(H),{style:{padding:"5px 25px"}},{breadcrumb:a(()=>{var c;return[(c=t.billingMetadata)!=null&&c.message?(n(),l(e(J),{key:0,type:"error",style:{position:"fixed",bottom:"0",left:"0",width:"100%","z-index":"1"}},R({message:a(()=>[s(e(C),{type:"secondary"},{default:a(()=>{var r;return[i(d((r=t.billingMetadata)==null?void 0:r.message),1)]}),_:1})]),_:2},[t.billingMetadata.messageLink?{name:"action",fn:a(()=>[s(e(m),{type:"primary",target:"_blank",href:t.billingMetadata.messageLink},{default:a(()=>{var r;return[i(d((r=t.billingMetadata.messageCTA)!=null?r:"Learn More"),1)]}),_:1},8,["href"])]),key:"0"}:void 0]),1024)):y("",!0),t.breadcrumb?(n(),l(e(z),{key:1},{default:a(()=>[(n(!0),k(P,null,T(t.breadcrumb,(r,_)=>(n(),l(e(G),{key:_},{default:a(()=>[s(e(F),{to:r.path},{default:a(()=>[i(d(r.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):y("",!0)]}),title:a(()=>[s(X)]),extra:a(()=>[s(Y)]),_:1}))}});export{ne as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.23562268.js.map
