import{v as o,a as r,b as i,c,j as d,T as p,k as f,P as _,C as u,M as l,s as g,l as s,m,n as y,p as b,q as v}from"./outputWidgets.f0391a74.js";import{s as w,a}from"./index.4f7b2ab2.js";import"./pubsub.73224ce6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="40069ea6-a3a6-440d-8672-fe94f5a6fb02",e._sentryDebugIdIdentifier="sentry-dbid-40069ea6-a3a6-440d-8672-fe94f5a6fb02")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=o(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>m(k)});p.init(),f(e,a),x.init(),e.use(a),e.use(_),e.mount("#app"),e.component("VSelect",u),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,b),s(e,v)})();
//# sourceMappingURL=player.d4407d9f.js.map
