import{d as h,eA as v,H as k,b as t,ev as f,u as e,c as s,ex as w,e as x,w as n,ew as C,bg as I,ar as u,aD as D,eC as N,f as c,eD as T,I as B,v as H}from"./outputWidgets.f0391a74.js";import{g as V}from"./api.bf4cc15a.js";import{a as z}from"./asyncComputed.363f961e.js";import{P as A}from"./PlayerNavbar.23eb39a3.js";import{e as F}from"./icons.f7511453.js";import"./index.75333136.js";import"./index.2bdeaa35.js";import{A as _}from"./index.9869cb58.js";import{T as y}from"./Typography.2e02df67.js";import{C as S}from"./Card.70d77b70.js";import"./runnerData.e6656cbd.js";import"./url.3db2a8aa.js";import"./index.4f7b2ab2.js";import"./pubsub.73224ce6.js";import"./repository.b2311d69.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Base.c690457d.js";import"./Link.39e3774a.js";import"./Paragraph.4c6547df.js";import"./Text.3e9cee86.js";import"./Title.18e0b53f.js";import"./TabPane.595c3088.js";import"./hasIn.23612021.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[i]="6f6c02e0-8976-4edd-8be0-4f1be5b7813c",a._sentryDebugIdIdentifier="sentry-dbid-6f6c02e0-8976-4edd-8be0-4f1be5b7813c")}catch{}})();const E={class:"page"},L=h({__name:"Home",setup(a){const i=v(),{result:r,loading:g}=z(V),m=k(()=>{var o,d;return(d=(o=r.value)==null?void 0:o.sidebar.filter(p=>p.visible))!=null?d:[]}),b=o=>{i.push({path:`/${o}`})};return(o,d)=>{var p;return t(),f("div",E,[e(r)?(t(),s(A,{key:0,"runner-data":e(r),"hide-sidebar":""},null,8,["runner-data"])):w("",!0),x("div",{class:"container",style:C({backgroundColor:(p=e(r))==null?void 0:p.theme})},[e(g)?(t(),s(e(I),{key:0})):m.value.length===0?(t(),s(e(y),{key:1,type:"secondary",style:{"font-size":"18px"}},{default:n(()=>[u(" There are no public forms available ")]),_:1})):(t(),s(e(_),{key:2,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:n(()=>[(t(!0),f(D,null,N(m.value,l=>(t(),s(e(S),{key:l.id,class:"form-card",onClick:P=>b(l.path)},{default:n(()=>[c(e(_),{gap:"large",align:"center",justify:"space-between"},{default:n(()=>[c(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:n(()=>[u(T(l.name),1)]),_:2},1024),c(B,{path:e(F),fill:"#000",width:"20"},null,8,["path"])]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}))],4)])}}});const pe=H(L,[["__scopeId","data-v-556afd7c"]]);export{pe as default};
//# sourceMappingURL=Home.3991b619.js.map
