import{d as w,eA as B,eB as D,H as v,r as N,b as t,c as d,w as o,ev as l,eC as y,u as i,cw as L,aD as g,bf as T,f as s,I as h,ar as V,eD as $,ex as k,bh as E,v as x,eE as P,eF as R,e as I,a as M}from"./outputWidgets.f0391a74.js";import{p as W,w as q,k as F,s as H,a as j,b as G,v as z,c as J,d as K}from"./icons.f7511453.js";import{_ as O}from"./logo.084e5d7c.js";import{B as Q}from"./BaseLayout.d6b28c70.js";import{N as U}from"./NavbarControls.e04b3d71.js";import{c as X}from"./index.58e79df5.js";import"./workspaces.0a261adb.js";import"./runnerData.e6656cbd.js";import"./url.3db2a8aa.js";import"./record.6f7f627d.js";import"./pubsub.73224ce6.js";import"./asyncComputed.363f961e.js";import"./envVars.2e25c3f4.js";import"./index.4f7b2ab2.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.7cb1b007.js";import"./ant-design.3b7d3c1c.js";import"./index.8b4d6f50.js";import"./Modal.7a75e616.js";import"./Typography.2e02df67.js";import"./Link.39e3774a.js";import"./Base.c690457d.js";import"./CloseCircleOutlined.23d63126.js";import"./index.03310b61.js";import"./popupNotifcation.bb922524.js";import"./index.9869cb58.js";import"./Text.3e9cee86.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.6af10b5d.js";import"./Paragraph.4c6547df.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="136b3098-0c2a-44b0-9d26-b254a9c50d5f",e._sentryDebugIdIdentifier="sentry-dbid-136b3098-0c2a-44b0-9d26-b254a9c50d5f")}catch{}})();const Y={key:0,class:"collapsible"},Z={key:1,class:"collapsible"},ee=w({__name:"Sidebar",setup(e){const n=B(),p=D();function _(){var m,r;return[(r=(m=b.value.map(a=>a.children).flat().find(a=>a.path===p.path))==null?void 0:m.name)!=null?r:"Workflow"]}const C=v(_),c=N(!1),f=()=>{c.value=!c.value},b=v(()=>[{name:"Project",children:[{name:"Stages",icon:W,path:"/_editor/stages"},{name:"Workflow",icon:q,path:"/_editor/workflow"},{name:"Threads",icon:F,path:"/_editor/kanban"}]},{name:"Settings",children:[{name:"Style",icon:H,path:"/_editor/style"},{name:"Sidebar",icon:j,path:"/_editor/sidebar"},{name:"Requirements",icon:G,path:"/_editor/requirements"},{name:"Env Vars",icon:z,path:"/_editor/env-vars"}]}]),A=u=>{n.push(u.path)};return(u,m)=>(t(),d(i(E),{"inline-collapsed":c.value,"selected-keys":C.value,style:{display:"flex","flex-direction":"column"}},{default:o(()=>[(t(!0),l(g,null,y(b.value,r=>(t(),d(i(L),{key:r.name,title:r.name},{default:o(()=>[(t(!0),l(g,null,y(r.children,a=>(t(),d(i(T),{key:a.name,role:"button",tabindex:"0",onClick:le=>A(a)},{icon:o(()=>[s(h,{path:a.icon,width:"18",height:"18"},null,8,["path"])]),default:o(()=>[V($(a.name),1)]),_:2},1032,["onClick"]))),128))]),_:2},1032,["title"]))),128)),c.value?(t(),l("div",Y,[s(h,{path:i(J),onClick:f},null,8,["path"])])):k("",!0),c.value?k("",!0):(t(),l("div",Z,[s(h,{path:i(K),onClick:f},null,8,["path"])]))]),_:1},8,["inline-collapsed","selected-keys"]))}});const te=x(ee,[["__scopeId","data-v-70171c75"]]);const oe={},S=e=>(P("data-v-81cd596e"),e=e(),R(),e),ae={class:"logo"},se=S(()=>I("img",{src:O,alt:"Abstra cloud logo"},null,-1)),ne=S(()=>I("span",null," Abstra ",-1)),re=[se,ne];function ie(e,n){return t(),l("div",ae,re)}const ce=x(oe,[["render",ie],["__scopeId","data-v-81cd596e"]]),We=w({__name:"Workspace",setup(e){return(n,p)=>{const _=M("router-view");return t(),d(Q,{"full-canvas":""},{navbar:o(()=>[s(i(X),{style:{padding:"5px 25px"}},{title:o(()=>[s(ce)]),extra:o(()=>[s(U,{"show-github-stars":"","show-v-s-code-button":""})]),_:1})]),sidebar:o(()=>[s(te,{class:"sidebar"})]),content:o(()=>[s(_)]),_:1})}}});export{We as default};
//# sourceMappingURL=Workspace.49dfb812.js.map
