import{d as b,eB as f,H as r,a as g,b as v,c as _,w as s,f as c}from"./outputWidgets.f0391a74.js";import{B as h}from"./BaseLayout.d6b28c70.js";import{a as y}from"./asyncComputed.363f961e.js";import"./router.9521f915.js";import"./index.13fb7824.js";import{P as z}from"./project.84b2ccef.js";import{O as w}from"./organization.472ebbc1.js";import{_ as I}from"./Navbar.vue_vue_type_script_setup_true_lang.23562268.js";import{S as j}from"./Sidebar.428fba9e.js";import{e as C,Q as O,R as k,S as B,T as M,v as S,G as L,U as P,V as x,M as D}from"./icons.f7511453.js";import"./Form.1aee5650.js";import"./hasIn.23612021.js";import"./popupNotifcation.bb922524.js";import"./index.cf4c23b9.js";import"./record.6f7f627d.js";import"./pubsub.73224ce6.js";import"./logo.084e5d7c.js";import"./Text.3e9cee86.js";import"./Base.c690457d.js";import"./Typography.2e02df67.js";import"./index.58e79df5.js";import"./ArrowRightOutlined.08fa31dd.js";import"./index.03310b61.js";import"./index.0e674df9.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[i]="4fbf6ecc-9252-44af-9b5f-5b1ba35fa5e3",t._sentryDebugIdIdentifier="sentry-dbid-4fbf6ecc-9252-44af-9b5f-5b1ba35fa5e3")}catch{}})();const ia=b({__name:"Project",setup(t){const l=f().params.projectId,{result:e}=y(()=>z.get(l).then(async a=>{const o=await w.get(a.organizationId);return{project:a,organization:o}})),m=r(()=>{var a,o,n,p;return((a=e.value)==null?void 0:a.organization)&&e.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(o=e.value)==null?void 0:o.organization)==null?void 0:n.name,path:`/organizations/${(p=e.value)==null?void 0:p.organization.id}`},{label:e.value.project.name,path:`/projects/${e.value.project.id}`}]:void 0}),u=r(()=>{var a;return(a=e.value)==null?void 0:a.organization.billingMetadata}),d=r(()=>{var a;return(a=e.value)!=null&&a.project?[{name:"Project",items:[{name:"Live",path:"live",icon:C},{name:"Builds",path:"builds",icon:O},{name:"Connectors",path:"connectors",icon:k,unavailable:!e.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:M},{name:"Env Vars",path:"env-vars",icon:S},{name:"Files",path:"files",icon:L},{name:"Logs",icon:P,path:"logs"},{name:"Settings",icon:x,path:"settings"},{name:"Users",icon:D,path:"users"}]}]:[]});return(a,o)=>{const n=g("router-view");return v(),_(h,null,{content:s(()=>[c(n)]),navbar:s(()=>[c(I,{class:"nav",breadcrumb:m.value,"billing-metadata":u.value},null,8,["breadcrumb","billing-metadata"])]),sidebar:s(()=>[c(j,{class:"sidebar",sections:d.value},null,8,["sections"])]),_:1})}}});export{ia as default};
//# sourceMappingURL=Project.e5071e7d.js.map
