.terminal[data-v-4e71a195]{margin-top:20px;width:96%;background-color:#212427;padding:12px 16px;border-radius:8px;overflow:scroll}.log-text[data-v-4e71a195]{color:#fff;margin:4px}.panel[data-v-68c9e478] .ant-collapse-header{padding:0}[data-v-12f0f0b7]:root{--main-font-family: DM Sans, sans-serif}[data-v-12f0f0b7]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-12f0f0b7]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-12f0f0b7]{background-color:#fff;padding:10px}.stage-column[data-v-12f0f0b7]{background-color:#e9eaeb;border-radius:6px;padding:8px}.stages-container[data-v-8d6c77ed]{max-width:100vw;position:relative;flex-grow:1}.stages-container .stages-content[data-v-8d6c77ed]{padding:20px;overflow:auto}.stages-container .stages-content[data-v-8d6c77ed] .ant-select-selection-item{display:flex;align-items:center}
