import{B as d}from"./Base.c690457d.js";import{A as o}from"./Link.39e3774a.js";import{A as r}from"./Paragraph.4c6547df.js";import{A as a}from"./Text.3e9cee86.js";import{A as i}from"./Title.18e0b53f.js";import{T as e}from"./Typography.2e02df67.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="e44ccad8-9044-4046-9ddb-153285527e99",n._sentryDebugIdIdentifier="sentry-dbid-e44ccad8-9044-4046-9ddb-153285527e99")}catch{}})();e.Text=a;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=d;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.75333136.js.map
