import{eQ as n,eR as t}from"./outputWidgets.f0391a74.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="b6834704-67bf-4348-8514-4b062eff666f",e._sentryDebugIdIdentifier="sentry-dbid-b6834704-67bf-4348-8514-4b062eff666f")}catch{}})();function s(e,f){return n(1,arguments),t(e,Date.now(),f)}export{s as f};
//# sourceMappingURL=index.a76f65f2.js.map
