import{F as t}from"./Form.1aee5650.js";import{b2 as r,cn as n}from"./outputWidgets.f0391a74.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d96e6044-9f48-4361-b322-0e7e015d621f",e._sentryDebugIdIdentifier="sentry-dbid-d96e6044-9f48-4361-b322-0e7e015d621f")}catch{}})();t.useInjectFormItemContext=r;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.702fae36.js.map
