import{K as n,L as p}from"./repository.f857e596.js";import{E as s}from"./repository.b2311d69.js";import{d as a,b as m,c,u as i}from"./outputWidgets.f0391a74.js";import{l as f}from"./index.4f7b2ab2.js";import"./asyncComputed.363f961e.js";import"./workspaces.0a261adb.js";import"./runnerData.e6656cbd.js";import"./url.3db2a8aa.js";import"./record.6f7f627d.js";import"./pubsub.73224ce6.js";import"./scripts.85b88d80.js";import"./envVars.2e25c3f4.js";import"./api.68844ee8.js";import"./index.cf4c23b9.js";import"./icons.f7511453.js";import"./contracts.generated.fbc14bdc.js";import"./index.9869cb58.js";import"./ant-design.3b7d3c1c.js";import"./index.8b4d6f50.js";import"./Modal.7a75e616.js";import"./Text.3e9cee86.js";import"./Base.c690457d.js";import"./Typography.2e02df67.js";import"./index.75333136.js";import"./Link.39e3774a.js";import"./Paragraph.4c6547df.js";import"./Title.18e0b53f.js";import"./index.0e674df9.js";import"./index.a76f65f2.js";import"./index.ef8659e9.js";import"./CollapsePanel.d211d636.js";import"./Timeline.ac53c0c9.js";import"./index.e5f19df8.js";import"./index.af266f0e.js";import"./isNumeric.75337b1e.js";import"./ExpandOutlined.a25309a8.js";import"./Card.70d77b70.js";import"./TabPane.595c3088.js";import"./hasIn.23612021.js";import"./DownOutlined.8e9db136.js";import"./index.702fae36.js";import"./Form.1aee5650.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="161928c5-5810-42f4-88a1-4b5557b9efb3",t._sentryDebugIdIdentifier="sentry-dbid-161928c5-5810-42f4-88a1-4b5557b9efb3")}catch{}})();class d{constructor(o=f){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const io=a({__name:"WorkflowKanban",setup(t){const o=new s,r=new d,e=new p("kanban");return(b,u)=>(m(),c(n,{"kanban-repository":i(o),storage:i(e),"stage-run-repository":i(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{io as default};
//# sourceMappingURL=WorkflowKanban.a151d788.js.map
