import{V as s,f as p,Q as d}from"./outputWidgets.f0391a74.js";import{B as f,b as i}from"./Base.c690457d.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="04f58daf-ce85-4a20-af63-a3103b758263",a._sentryDebugIdIdentifier="sentry-dbid-04f58daf-ce85-4a20-af63-a3103b758263")}catch{}})();const y=()=>d(i(),["component"]),r=(a,e)=>{let{slots:t,attrs:o}=e;const n=s(s(s({},a),{component:"div"}),o);return p(f,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=y();const b=r;export{b as A};
//# sourceMappingURL=Paragraph.4c6547df.js.map
