import{cy as b}from"./outputWidgets.f0391a74.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="0524b927-bd10-45c5-b7de-de6bb7b2ae75",e._sentryDebugIdIdentifier="sentry-dbid-0524b927-bd10-45c5-b7de-de6bb7b2ae75")}catch{}})();const o=(e,d,r)=>{b.error({message:e,description:d,onClick:r})};export{o as p};
//# sourceMappingURL=popupNotifcation.bb922524.js.map
