import{g as d}from"./api.bf4cc15a.js";import{P as f}from"./Passwordless.e5e4e0e6.js";import{a as m}from"./asyncComputed.363f961e.js";import{W as p}from"./WidgetsFrame.cd5304d0.js";import{d as u,eA as l,eB as _,b as i,ev as y,e as g,u as a,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.f0391a74.js";import"./runnerData.e6656cbd.js";import"./url.3db2a8aa.js";import"./index.4f7b2ab2.js";import"./pubsub.73224ce6.js";import"./index.03310b61.js";import"./icons.f7511453.js";import"./CircularLoading.d9f967cd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="34640f3f-51aa-461a-8f43-a1001ebf2cfc",e._sentryDebugIdIdentifier="sentry-dbid-34640f3f-51aa-461a-8f43-a1001ebf2cfc")}catch{}})();const x={class:"login"},I=u({__name:"Login",setup(e){const t=l(),s=_(),{result:o}=m(d),c=()=>{const{redirect:r,...n}=s.query;if(r){t.push({path:r,query:n,params:s.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(i(),y("div",null,[g("div",x,[a(o)?(i(),b(p,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(f,{onDone:c})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const A=k(I,[["__scopeId","data-v-33714d9d"]]);export{A as default};
//# sourceMappingURL=Login.a8db39b7.js.map
