import{f as d,eG as i,eS as u}from"./outputWidgets.f0391a74.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8b66def3-dc3e-4af1-aafe-9ca63fc83de6",e._sentryDebugIdIdentifier="sentry-dbid-8b66def3-dc3e-4af1-aafe-9ca63fc83de6")}catch{}})();function o(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){c(e,a,n[a])})}return e}function c(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var f=function(t,n){var r=o({},t,n.attrs);return d(i,o({},r,{icon:u}),null)};f.displayName="DownOutlined";f.inheritAttrs=!1;const s=f;export{s as D};
//# sourceMappingURL=DownOutlined.8e9db136.js.map
